Temperature conduction
======================

This example solves the 1D temperature conduction problem. See the
[documentation][conduction] for a line-by-line walkthrough of this model.


[conduction]: https://bout-dev.readthedocs.io/en/latest/user_docs/physics_models.html#heat-conduction
